summaryrefslogtreecommitdiff
path: root/release/sysinstall/system.c
diff options
context:
space:
mode:
authorJordan K. Hubbard <jkh@FreeBSD.org>1997-04-28 10:34:42 +0000
committerJordan K. Hubbard <jkh@FreeBSD.org>1997-04-28 10:34:42 +0000
commita13546d7e7e170a0b42beba72ec10a95f018ee4c (patch)
treeeb6461825d8232a27a69a8d6e2907229a471e8aa /release/sysinstall/system.c
parent98bbf54ffa977e6ad4316a126c168c8855957731 (diff)
Notes
Diffstat (limited to 'release/sysinstall/system.c')
-rw-r--r--release/sysinstall/system.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/release/sysinstall/system.c b/release/sysinstall/system.c
index 142debef1005..416fc0ee185a 100644
--- a/release/sysinstall/system.c
+++ b/release/sysinstall/system.c
@@ -4,7 +4,7 @@
* This is probably the last program in the `sysinstall' line - the next
* generation being essentially a complete rewrite.
*
- * $Id: system.c,v 1.66.2.9 1997/04/28 06:22:15 jkh Exp $
+ * $Id: system.c,v 1.66.2.10 1997/04/28 09:17:33 jkh Exp $
*
* Jordan Hubbard
*
@@ -118,9 +118,9 @@ systemShutdown(int status)
if (status >=0 && mediaDevice)
mediaDevice->shutdown(mediaDevice);
- /* write out any changes to sysconfig .. */
- if (!status)
- configSysconfig("/etc/sysconfig");
+ /* write out any changes to rc.conf .. */
+ if (status)
+ configRC_conf("/etc/rc.conf");
/* Shut down the dialog library */
if (DialogActive) {